#!/bin/bash

# Update package index
apt update

# Install necessary prerequisites
apt install -y apt-transport-https ca-certificates curl software-properties-common gnupg-agent

# Add Docker’s official GPG key
curl -fsSL https://download.docker.com/linux/ubuntu/gpg | sudo gpg --dearmor -o /usr/share/keyrings/docker-archive-keyring.gpg

# Add Docker APT repository
echo "deb [arch=amd64 signed-by=/usr/share/keyrings/docker-archive-keyring.gpg] https://download.docker.com/linux/ubuntu $(lsb_release -cs) stable" | sudo tee /etc/apt/sources.list.d/docker.list > /dev/null

# Update package index again
apt update

# Install Docker version 24.0.2
apt install -y docker-ce=5:24.0.2-1~ubuntu.20.04~focal docker-ce-cli=5:24.0.2-1~ubuntu.20.04~focal containerd.io

# Start and enable Docker
systemctl start docker
systemctl enable docker

# Verify Docker installation
docker --version

# Create Docker group if it doesn't exist
if ! getent group docker > /dev/null; then
  groupadd docker
fi

# Add the current user to the Docker group
usermod -aG docker $USER

# Install Portainer 1.20.2
docker volume create portainer_data

docker run -d -p 80:9000 --name=portainer --restart=always \
  -v /var/run/docker.sock:/var/run/docker.sock \
  -v portainer_data:/data portainer/portainer

# Verify Portainer installation
docker ps -a

echo "Docker 24.0.2 and Portainer 1.20.2 have been installed successfully. Portainer is running on port 80."

# End of script
